@@ -4,7 +4,7 @@
  * --------
  * Author: Nigel McNie (nigel@geshi.org)
  * Copyright: (c) 2004 Nigel McNie (http://qbnz.com/highlighter/)
- * Release Version: 1.0.7.19
+ * Release Version: 1.0.7.20
  * Date Started: 2004/06/20
  *
  * PHP language file for GeSHi.
@@ -348,7 +348,8 @@ $language_data = array (
         1 => true,
         2 => true,
         3 => true
-        )
+        ),
+    'TAB_WIDTH' => 4
 );
 
 ?>
